@@ -1,4 +1,6 @@
+pub mod any;
 pub mod bool;
 pub mod iter;
 pub mod option;
+pub mod panic;
 pub mod result;
